@@ -27,7 +27,7 @@ Interface::Interface(Screen &s, iToDo &t, Sched& sch, Config &c, Writer &w, Cmd
 {
 	cmd.get_interface(this);
 
-	search_pattern = "";
+	search_pattern = L"";
 	tree_begin = 0;
 	tree_end = screen.treeLines();
 
@@ -44,7 +44,7 @@ Interface::~Interface()
 
 void Interface::main()
 {
-	int key;
+	int key; //TODO: migrate to utf
 	string action;
 
 	while (cursor.out());
@@ -266,10 +266,8 @@ bool Interface::isHide(iToDo& todo)
 	return hide;
 }
 
-void Interface::newTodo()
+void Interface::inherit()
 {
-	cursor.addChild(new ToDo());
-
 	/* inherit category */
 	if (cursor.depth())
 	{
@@ -277,9 +275,9 @@ void Interface::newTodo()
 		father.out();
 		cursor->setCategory(father->getCategory());
 	}
-	else if (hidden_categories.count(""))
+	else if (hidden_categories.count(L""))
 	{
-		set<string>::iterator cat;
+		set<wstring>::iterator cat;
 		for (cat = categories.begin(); (cat != categories.end()) && hidden_categories.count(*cat); cat++);
 		if (cat != categories.end()) cursor->setCategory(*cat);
 		else cursor->setCategory(NONE_CATEGORY);
@@ -294,7 +292,10 @@ void Interface::left()
 		up();
 	}
 	else if (isHide(cursor))
-		newTodo();
+	{
+		cursor.addChild(new ToDo());
+		inherit();
+	}
 	cursor->actCollapse() = false;
 	if (cursor->getCollapse())
 	{
@@ -317,10 +318,11 @@ void Interface::right()
 
 	if (cursor.end())
 	{
-		newTodo();
+		cursor.addChild(new ToDo());
+		inherit();
 		drawTodo();
-		string title;
-		if ((editLine(title)) && (title != ""))
+		wstring title;
+		if ((editLine(title)) && (title != L""))
 		{
 			cursor->getTitle() = title;
 
@@ -349,6 +351,11 @@ void Interface::right()
 void Interface::up()
 {
 	eraseCursor();
+	if (cursor.begin())
+	{
+		/* Jump to end if beginning reached */
+		while (++cursor);
+	}
 	--cursor;
 
 	/* Jump hide tasks */
@@ -375,7 +382,11 @@ void Interface::down()
 {
 	eraseCursor();
 	++cursor;
-	if (cursor.end()) --cursor;
+	if (cursor.end())
+	{
+		/* Jump to beginning if end reached */
+		while (--cursor);
+	}
 
 	/* Jump hide tasks */
 	while (isHide(cursor))
@@ -496,7 +507,7 @@ void Interface::pasteChild()
 
 #define startTitle (cursor.depth() * 4 + 7)
 
-bool Interface::editLine(string& str)
+bool Interface::editLine(wstring& str)
 {
 	bool save;
 
@@ -534,10 +545,11 @@ void Interface::setCategory()
 
 void Interface::addLine()
 {
-	newTodo();
+	cursor.addChild(new ToDo());
+	inherit();
 	drawTodo();
-	string title;
-	if ((editLine(title)) && (title != ""))
+	wstring title;
+	if ((editLine(title)) && (title != L""))
 		cursor->getTitle() = title;
 	else
 		del();
@@ -545,10 +557,11 @@ void Interface::addLine()
 
 void Interface::addLineUp()
 {
-	newTodo();
+	cursor.addChildUp(new ToDo());
+	inherit();
 	drawTodo();
-	string title;
-	if ((editLine(title)) && (title != ""))
+	wstring title;
+	if ((editLine(title)) && (title != L""))
 		cursor->getTitle() = title;
 	else
 		del();
@@ -556,7 +569,7 @@ void Interface::addLineUp()
 
 void Interface::modifyLine()
 {
-	string title;
+	wstring title;
 	if (editLine(title))
 		cursor->getTitle() = title;
 }
@@ -571,7 +584,7 @@ void Interface::editText()
 		char* argv[32];
 		int argc;
 		char* res;
-		string str;
+		wstring str;
 		Text& text = cursor->getText();
 
 		/* create a temporal file */
@@ -581,7 +594,7 @@ void Interface::editText()
                         tmpnam(path);                                                                            
                 close(fout);
 
-		ofstream ofs(path);
+		wofstream ofs(path);
 		ofs << text;
 		ofs.close();
 		sprintf(s, editor, path);
@@ -711,7 +724,7 @@ bool Interface::_search()
 
 void Interface::command_line()
 {
-	string command("");
+	wstring command(L"");
 
 	if (screen.cmd(command))
 	{
@@ -728,7 +741,7 @@ void Interface::command_line()
 
 void Interface::search()
 {
-	string pattern("");
+	wstring pattern(L"");
 
 	if (screen.searchText(pattern))
 	{
@@ -742,7 +755,7 @@ void Interface::search()
 
 void Interface::search_next()
 {
-	if (search_pattern != "")
+	if (search_pattern != L"")
 		if (_search())
 			drawTodo();
 		else
@@ -753,7 +766,7 @@ void Interface::search_next()
 
 void Interface::search_prev()
 {
-	if (search_pattern != "")
+	if (search_pattern != L"")
 		if (_search())
 			drawTodo();
 		else
