@@ -20,21 +20,7 @@
 #ifndef INTERFACE_H
 #define INTERFACE_H
 
-#include <ncurses.h>
-#include <signal.h>
-#include <string.h>
-#include <form.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <map>
-#include <set>
-#include <fstream>
-
+#include "defs.h"
 class Interface;
 #include "data.h"
 #include "sched.h"
@@ -44,7 +30,6 @@ class Interface;
 #include "screen.h"
 #include "cmd.h"
 
-
 class Interface
 {
 public:
@@ -63,9 +48,9 @@ private:
 	int tree_begin, tree_end;
 	pToDo copied;
 	char sortOrder[16];
-	string search_pattern;
+	wstring search_pattern;
 	Cmd &cmd; /* command interface */
-	set<string> hidden_categories;
+	set<wstring> hidden_categories;
 
 	void resizeTerm();
 	void drawTodo();
@@ -74,7 +59,7 @@ private:
 	void eraseCursor();
 	void drawCursor();
 	bool isHide(iToDo& todo);
-	void newTodo();
+	void inherit();
 	void left();
 	void right();
 	void up();
@@ -89,7 +74,7 @@ private:
 	void paste();
 	void pasteUp();
 	void pasteChild();
-	bool editLine(string& str);
+	bool editLine(wstring& str);
 	void editDeadline();
 	void setPriority();
 	void setCategory();
